@@ -28,7 +28,6 @@ class GraphManager(WorkFlowManager):
     jobs_graph = {}
 
     def __init__(self):
-        self.__failed_outcomes = list(self.base_failed_outcomes)
         # Ensure jobs are traversed in the same order as they went pending.
         self.__pending_jobs = odict()
         self.__running_jobs = odict()
@@ -62,10 +61,6 @@ class GraphManager(WorkFlowManager):
     def configure_workflow(self):
         raise NotImplementedError("configure_workflow() method need to be implemented.")
 
-    def resume_workflow(self):
-        # TODO: implement
-        raise NotImplementedError()
-
     def on_start(self):
         if not self.jobs_graph:
             self.argparser.error("Jobs graph configuration is empty.")
@@ -211,8 +206,6 @@ class GraphManager(WorkFlowManager):
         args = super(GraphManager, self).parse_args()
         self.jobs_graph = yaml.load(args.jobs_graph) or deepcopy(self.jobs_graph)
 
-        if not self.name:
-            self.argparser.error("Manager name not set.")
         if args.starting_job and args.root_jobs:
             self.argparser.error("You can't provide both --starting-job and --root-jobs.")
         return args
@@ -401,7 +394,7 @@ class GraphManager(WorkFlowManager):
         on_finish = self.get_job(job)["on_finish"]
         if outcome in on_finish:
             nextjobs = on_finish[outcome]
-        elif outcome in self.__failed_outcomes:
+        elif outcome in self.failed_outcomes:
             nextjobs = on_finish.get("failed", [])
         else:
             nextjobs = on_finish["default"]
